@@ -247,12 +247,13 @@ class NewProductAnalysisManager:
         finally:
             session.close()
 
-    def _extract_prom_info(self, prom_list):
+    def _extract_prom_info(self, prom_list, current_skc=None):
         """
         提取促销活动信息
         
         Args:
             prom_list (list): 促销活动列表
+            current_skc (str): 当前SKC，用于从promDetail中筛选匹配的记录
             
         Returns:
             list: 提取后的促销活动信息列表
@@ -272,25 +273,42 @@ class NewProductAnalysisManager:
             prom_id = prom.get('promId', '')
             prom_detail = prom.get('promDetail', [])
 
+            # 如果提供了current_skc，从promDetail中筛选匹配的记录
+            if current_skc and prom_detail and isinstance(prom_detail, list):
+                # 查找匹配当前SKC的detail记录
+                matched_detail = None
+                for detail in prom_detail:
+                    if isinstance(detail, dict) and detail.get('skc') == current_skc:
+                        matched_detail = detail
+                        break
+                
+                # 如果找到匹配的记录，使用它；否则使用第一个
+                if matched_detail:
+                    prom_detail = [matched_detail]
+                # 如果没找到匹配的，保持原样（使用第一个）
+
             # 根据promId长度判断取哪些字段
             if len(str(prom_id)) >= 11 and prom_detail:
                 # 营销工具：取第一个detail的数据
-                detail = prom_detail if prom_detail else {}
-                prom_info['attend_num_sum'] = detail.get('act_stock_num')
-                prom_info['supply_price'] = detail.get('sku_price')
-                prom_info['product_act_price'] = detail.get('act_sku_price')
+                detail = prom_detail[0] if isinstance(prom_detail, list) else prom_detail
+                if isinstance(detail, dict):
+                    prom_info['attend_num_sum'] = detail.get('act_stock_num') or detail.get('attend_num_sum')
+                    prom_info['supply_price'] = detail.get('sku_price') or detail.get('supply_price')
+                    prom_info['product_act_price'] = detail.get('act_sku_price') or detail.get('product_act_price')
             elif len(str(prom_id)) >= 8 and prom_detail:
                 # 营销工具：取第一个detail的数据
-                detail = prom_detail[0] if prom_detail else {}
-                prom_info['attend_num_sum'] = detail.get('attend_num_sum')
-                prom_info['supply_price'] = detail.get('supply_price')
-                prom_info['product_act_price'] = detail.get('product_act_price')
+                detail = prom_detail[0] if isinstance(prom_detail, list) else prom_detail
+                if isinstance(detail, dict):
+                    prom_info['attend_num_sum'] = detail.get('attend_num_sum')
+                    prom_info['supply_price'] = detail.get('supply_price')
+                    prom_info['product_act_price'] = detail.get('product_act_price')
             elif prom_detail:
                 # 营销活动：取第一个detail的数据
-                detail = prom_detail[0] if prom_detail else {}
-                prom_info['attend_num'] = detail.get('attend_num')
-                prom_info['goods_cost'] = detail.get('goods_cost')
-                prom_info['attend_cost'] = detail.get('attend_cost')
+                detail = prom_detail[0] if isinstance(prom_detail, list) else prom_detail
+                if isinstance(detail, dict):
+                    prom_info['attend_num'] = detail.get('attend_num')
+                    prom_info['goods_cost'] = detail.get('goods_cost')
+                    prom_info['attend_cost'] = detail.get('attend_cost')
 
             result.append(prom_info)
 
@@ -325,10 +343,10 @@ class NewProductAnalysisManager:
                 skipped_count += 1
                 continue
 
-            # 提取促销活动信息
+            # 提取促销活动信息（传入当前SKC以筛选匹配的促销信息）
             prom_campaign = item.get('promCampaign', {})
-            prom_inf_ing = self._extract_prom_info(prom_campaign.get('promInfIng'))
-            prom_inf_ready = self._extract_prom_info(prom_campaign.get('promInfReady'))
+            prom_inf_ing = self._extract_prom_info(prom_campaign.get('promInfIng'), current_skc=skc)
+            prom_inf_ready = self._extract_prom_info(prom_campaign.get('promInfReady'), current_skc=skc)
 
             # 提取AB测试信息（去掉product_name字段）
             ab_test = item.get('ab_test', {})
