@@ -198,6 +198,68 @@ class SheinReturnOrderDetail(Base):
     def __repr__(self):
         return f"<SheinReturnOrderDetail(id={self.id}, skc='{self.skc}', return_quantity={self.return_quantity})>"
 
+class SheinReturnOrderGoodsDetail(Base):
+    """
+    SHEIN退货商品明细表
+    存储退货商品明细信息(来自return_order_goods_detail接口)
+    与SheinReturnOrderDetail并存,专注于商品维度数据
+    """
+    __tablename__ = 'shein_return_order_goods_detail'
+
+    # 主键ID
+    id = Column(Integer, primary_key=True, autoincrement=True, comment='主键ID')
+
+    # 关联退货单ID
+    return_order_id = Column(Integer, nullable=True, comment='关联退货单ID')
+
+    # SKC级别信息
+    img_path = Column(Text, nullable=True, comment='商品图片路径')
+    skc = Column(String(50), nullable=True, comment='SKC编码')
+    skc_copy_flag = Column(Integer, nullable=True, comment='SKC复制标志')
+    supplier_code = Column(String(100), nullable=True, comment='供应商编码')
+    pre_return_quantity = Column(Integer, nullable=True, comment='SKC级别预退货数量')
+    return_quantity = Column(Integer, nullable=True, comment='SKC级别实际退货数量')
+    scrap_quantity = Column(Integer, nullable=True, comment='SKC级别报废数量')
+    skc_mark_flag_name = Column(String(100), nullable=True, comment='SKC标记名称')
+    skc_slow_moving_flag = Column(Integer, nullable=True, comment='滞销标志')
+
+    # SKU级别信息(来自details数组)
+    platform_sku = Column(String(50), nullable=True, comment='平台SKU')
+    supplier_sku = Column(String(100), nullable=True, comment='供应商SKU')
+    suffix_zh = Column(String(100), nullable=True, comment='中文规格(如"黑色-M")')
+    sku_pre_return_quantity = Column(Integer, nullable=True, comment='SKU级别预退货数量')
+    sku_return_quantity = Column(Integer, nullable=True, comment='SKU级别实际退货数量')
+    sku_scrap_quantity = Column(Integer, nullable=True, comment='SKU级别报废数量')
+    seller_order_no = Column(String(50), nullable=True, comment='卖家订单号')
+    seller_delivery_no = Column(String(50), nullable=True, comment='卖家发货单号')
+    order_type = Column(Integer, nullable=True, comment='订单类型')
+
+    # ERP扩展信息
+    erp_supplier_name = Column(String(50), nullable=True, comment='ERP供应商名称')
+    erp_cost_price = Column(DECIMAL(10, 2), nullable=True, comment='ERP成本价')
+
+    # 业务字段
+    sign_quantity = Column(Integer, nullable=True, comment='仓库签收数量')
+    sign_at = Column(DateTime, nullable=True, comment='仓库签收时间')
+    return_factotry_status = Column(Integer, nullable=True, comment='退回工厂状态,1已退回,2未退回')
+    return_factotry_by = Column(String(50), nullable=True, comment='退回工厂操作人')
+    financial_settlement_status = Column(Integer, nullable=True, comment='财务结算状态,1已结算,2未结算')
+    detail_notes = Column(Text, nullable=True, comment='明细备注')
+
+    # 时间戳
+    created_at = Column(DateTime, default=datetime.now, comment='创建时间')
+    updated_at = Column(DateTime, default=datetime.now, onupdate=datetime.now, comment='更新时间')
+
+    # 定义索引
+    __table_args__ = (
+        Index('ix_goods_return_order_id', 'return_order_id'),
+        Index('ix_goods_supplier_sku', 'supplier_sku'),
+        Index('ix_goods_platform_sku', 'platform_sku'),
+    )
+
+    def __repr__(self):
+        return f"<SheinReturnOrderGoodsDetail(id={self.id}, skc='{self.skc}', sku_return_quantity={self.sku_return_quantity})>"
+
 class SheinReturnOrderManager:
     """
     SHEIN退货订单数据管理器
@@ -345,9 +407,12 @@ class SheinReturnOrderManager:
         session.add(return_order)
         session.flush()  # 获取主键ID
 
-        # 插入明细记录
+        # 插入包裹明细记录(return_box_detail)
         self._insert_return_order_details(session, return_order.id, data.get('return_box_detail', []))
 
+        # 插入商品明细记录(return_goods_detail)
+        self._insert_return_order_goods_details(session, return_order.id, data.get('return_goods_detail', []))
+
     def _update_return_order(self, session, existing_order, data):
         """
         更新现有的退货单记录（保留用户备注,只更新下面这些替换的）
@@ -412,13 +477,17 @@ class SheinReturnOrderManager:
         existing_order.complete_time = self._parse_datetime(data.get('completeTime'))
         existing_order.updated_at = datetime.now()
 
-        # 不更新 明细记录
+        # 不更新包裹明细记录(保持原有逻辑)
         # # 删除旧的明细记录
         # session.query(SheinReturnOrderDetail).filter_by(return_order_id=existing_order.id).delete()
 
         # # 插入新的明细记录
         # self._insert_return_order_details(session, existing_order.id, data.get('return_box_detail', []))
 
+        # 更新商品明细记录(如果有return_goods_detail数据)
+        if data.get('return_goods_detail'):
+            self._update_return_order_goods_details(session, existing_order.id, data.get('return_goods_detail', []))
+
     def _insert_return_order_details(self, session, return_order_id, return_box_details):
         """
         插入退货明细记录
@@ -461,6 +530,144 @@ class SheinReturnOrderManager:
                         )
                         session.add(detail_record)
 
+    def _insert_return_order_goods_details(self, session, return_order_id, return_goods_details):
+        """
+        插入退货商品明细记录
+        数据来源: return_order_goods_detail接口
+        """
+        for goods_item in return_goods_details:
+            # SKC级别信息
+            img_path = goods_item.get('imgPath')
+            skc = goods_item.get('skc')
+            skc_copy_flag = goods_item.get('skcCopyFlag')
+            supplier_code = goods_item.get('supplierCode')
+            pre_return_quantity = goods_item.get('preReturnQuantity')
+            return_quantity = goods_item.get('returnQuantity')
+            scrap_quantity = goods_item.get('scrapQuantity')
+            skc_mark_flag_name = goods_item.get('skcMarkFlagName')
+            skc_slow_moving_flag = goods_item.get('skcSlowMovingFlag')
+
+            # 遍历SKU明细
+            for detail in goods_item.get('details', []):
+                goods_detail_record = SheinReturnOrderGoodsDetail(
+                    return_order_id=return_order_id,
+                    # SKC级别信息
+                    img_path=img_path,
+                    skc=skc,
+                    skc_copy_flag=skc_copy_flag,
+                    supplier_code=supplier_code,
+                    pre_return_quantity=pre_return_quantity,
+                    return_quantity=return_quantity,
+                    scrap_quantity=scrap_quantity,
+                    skc_mark_flag_name=skc_mark_flag_name,
+                    skc_slow_moving_flag=skc_slow_moving_flag,
+                    # SKU级别信息
+                    platform_sku=detail.get('platformSku'),
+                    supplier_sku=detail.get('supplierSku'),
+                    suffix_zh=detail.get('suffixZh'),
+                    sku_pre_return_quantity=detail.get('preReturnQuantity'),
+                    sku_return_quantity=detail.get('returnQuantity'),
+                    sku_scrap_quantity=detail.get('scrapQuantity'),
+                    seller_order_no=detail.get('sellerOrderNo'),
+                    seller_delivery_no=detail.get('sellerDeliveryNo'),
+                    order_type=detail.get('orderType'),
+                    # ERP扩展信息
+                    erp_supplier_name=detail.get('erp_supplier_name'),
+                    erp_cost_price=detail.get('erp_cost_price')
+                )
+                session.add(goods_detail_record)
+
+    def _update_return_order_goods_details(self, session, return_order_id, return_goods_details):
+        """
+        更新退货商品明细记录
+        策略: 基于supplier_sku匹配更新,保留手动填写的字段(签收数量、退回状态、财务结算状态等)
+        """
+        for goods_item in return_goods_details:
+            # SKC级别信息
+            img_path = goods_item.get('imgPath')
+            skc = goods_item.get('skc')
+            skc_copy_flag = goods_item.get('skcCopyFlag')
+            supplier_code = goods_item.get('supplierCode')
+            pre_return_quantity = goods_item.get('preReturnQuantity')
+            return_quantity = goods_item.get('returnQuantity')
+            scrap_quantity = goods_item.get('scrapQuantity')
+            skc_mark_flag_name = goods_item.get('skcMarkFlagName')
+            skc_slow_moving_flag = goods_item.get('skcSlowMovingFlag')
+
+            # 遍历SKU明细
+            for detail in goods_item.get('details', []):
+                supplier_sku = detail.get('supplierSku')
+                platform_sku = detail.get('platformSku')
+
+                # 尝试查找现有记录(通过return_order_id + supplier_sku匹配)
+                existing_record = session.query(SheinReturnOrderGoodsDetail).filter_by(
+                    return_order_id=return_order_id,
+                    supplier_sku=supplier_sku
+                ).first()
+
+                if existing_record:
+                    # 更新现有记录(只更新接口返回的字段,保留手动填写的字段)
+                    # SKC级别信息
+                    existing_record.img_path = img_path
+                    existing_record.skc = skc
+                    existing_record.skc_copy_flag = skc_copy_flag
+                    existing_record.supplier_code = supplier_code
+                    existing_record.pre_return_quantity = pre_return_quantity
+                    existing_record.return_quantity = return_quantity
+                    existing_record.scrap_quantity = scrap_quantity
+                    existing_record.skc_mark_flag_name = skc_mark_flag_name
+                    existing_record.skc_slow_moving_flag = skc_slow_moving_flag
+                    # SKU级别信息
+                    existing_record.platform_sku = platform_sku
+                    existing_record.suffix_zh = detail.get('suffixZh')
+                    existing_record.sku_pre_return_quantity = detail.get('preReturnQuantity')
+                    existing_record.sku_return_quantity = detail.get('returnQuantity')
+                    existing_record.sku_scrap_quantity = detail.get('scrapQuantity')
+                    existing_record.seller_order_no = detail.get('sellerOrderNo')
+                    existing_record.seller_delivery_no = detail.get('sellerDeliveryNo')
+                    existing_record.order_type = detail.get('orderType')
+                    # ERP扩展信息
+                    existing_record.erp_supplier_name = detail.get('erp_supplier_name')
+                    existing_record.erp_cost_price = detail.get('erp_cost_price')
+                    existing_record.updated_at = datetime.now()
+
+                    # 不更新的字段(保留手动填写的值):
+                    # - sign_quantity (仓库签收数量)
+                    # - sign_at (仓库签收时间)
+                    # - return_factotry_status (退回工厂状态)
+                    # - return_factotry_by (退回工厂操作人)
+                    # - financial_settlement_status (财务结算状态)
+                    # - detail_notes (明细备注)
+                else:
+                    # 插入新记录
+                    goods_detail_record = SheinReturnOrderGoodsDetail(
+                        return_order_id=return_order_id,
+                        # SKC级别信息
+                        img_path=img_path,
+                        skc=skc,
+                        skc_copy_flag=skc_copy_flag,
+                        supplier_code=supplier_code,
+                        pre_return_quantity=pre_return_quantity,
+                        return_quantity=return_quantity,
+                        scrap_quantity=scrap_quantity,
+                        skc_mark_flag_name=skc_mark_flag_name,
+                        skc_slow_moving_flag=skc_slow_moving_flag,
+                        # SKU级别信息
+                        platform_sku=platform_sku,
+                        supplier_sku=supplier_sku,
+                        suffix_zh=detail.get('suffixZh'),
+                        sku_pre_return_quantity=detail.get('preReturnQuantity'),
+                        sku_return_quantity=detail.get('returnQuantity'),
+                        sku_scrap_quantity=detail.get('scrapQuantity'),
+                        seller_order_no=detail.get('sellerOrderNo'),
+                        seller_delivery_no=detail.get('sellerDeliveryNo'),
+                        order_type=detail.get('orderType'),
+                        # ERP扩展信息
+                        erp_supplier_name=detail.get('erp_supplier_name'),
+                        erp_cost_price=detail.get('erp_cost_price')
+                    )
+                    session.add(goods_detail_record)
+
     def get_return_orders(self, limit=None, offset=None):
         """
         查询退货单列表
