@@ -640,7 +640,7 @@ class TimeUtils:
         return create_time.date() == yesterday.date()
 
     @staticmethod
-    def is_yesterday_date(date_str: str) -> bool:
+    def is_yesterday_date(date_str: str, format="%Y-%m-%d") -> bool:
         """
         判断给定的日期字符串是否是昨天
         
@@ -651,7 +651,7 @@ class TimeUtils:
             如果 date_str 是昨天的日期，返回 True，否则返回 False
         """
         try:
-            create_time = datetime.strptime(date_str, "%Y-%m-%d")
+            create_time = datetime.strptime(date_str, format)
             dt = datetime.now()
         except ValueError:
             raise ValueError("时间字符串格式不正确，请使用正确的格式：'%Y-%m-%d'")
